[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.
From: |
guix-commits |
Subject: |
410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools. |
Date: |
Mon, 29 May 2023 17:39:48 -0400 (EDT) |
ngz pushed a commit to branch tex-team-next
in repository guix.
commit 026533bf8365726eeb7afcd2b7c84cf26ccc1461
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
AuthorDate: Sat May 20 09:45:22 2023 +0200
gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.
* gnu/packages/tex.scm (texlive-xindy)[source]: Use TEXLIVE-ORIGIN.
[build-system]: Use TEXLIVE-BUILD-SYSTEM.
[arguments]<#:phases>: Also set Perl executable location in scripts.
---
gnu/packages/tex.scm | 71 +++++++++++++++++++++++++---------------------------
1 file changed, 34 insertions(+), 37 deletions(-)
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index ff624bef77..defb09a2c8 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -12176,49 +12176,46 @@ handle complex tests.")
(define-public texlive-xindy
(package
(name "texlive-xindy")
- (version "2.5.1")
- (source (origin
- (method url-fetch)
- (uri (string-append "mirror://ctan/indexing/xindy/base/xindy-"
- version ".tar.gz"))
- (sha256
- (base32
- "0hxsx4zw19kmixkmrln17sxgg1ln4pfp4lpfn5v5fyr1nwfyk3ic"))))
- (build-system gnu-build-system)
+ (version (number->string %texlive-revision))
+ (source (texlive-origin
+ name version
+ (list "doc/man/man1/tex2xindy.1"
+ "doc/man/man1/tex2xindy.man1.pdf"
+ "doc/man/man1/texindy.1"
+ "doc/man/man1/texindy.man1.pdf"
+ "doc/man/man1/xindy.1"
+ "doc/man/man1/xindy.man1.pdf"
+ "doc/xindy/"
+ "scripts/xindy/"
+ "xindy/")
+ (base32
+ "0rgzckyy6w4rmgxins5kakllkpn2hrccaps7lwb8h2nzvd29yj3m")))
+ (outputs '("out" "doc"))
+ (build-system texlive-build-system)
(arguments
(list
- #:configure-flags #~(list "--enable-docs")
#:phases
#~(modify-phases %standard-phases
- (add-after 'unpack 'patch-clisp
+ (add-after 'unpack 'patch-inputs
(lambda* (#:key inputs #:allow-other-keys)
- ;; The xindy.in file is encoded in ISO-8859-1 (or iso-latin-1).
- (with-fluids ((%default-port-encoding "ISO-8859-1"))
- (substitute* "user-commands/xindy.in"
- (("(our \\$clisp = ).*" _ head)
- (format #f "our $clisp = ~s;~%"
- (search-input-file inputs "bin/clisp"))))))))))
- (native-inputs (list clisp
- glibc-locales
- perl
- texlive-bin
- texlive-greek-fontenc
- texlive-hyperref
- texlive-latex-base
- texlive-cyrillic
- texlive-geometry
- (texlive-updmap.cfg ;fonts
- (list texlive-cbfonts
- texlive-lh
- texlive-jknapltx))))
- (inputs (list clisp perl)) ;used at run time
- (home-page "https://www.ctan.org/pkg/xindy")
+ (with-directory-excursion "scripts/xindy/"
+ ;; The scripts are encoded in ISO-8859-1 (or iso-latin-1).
+ (with-fluids ((%default-port-encoding "ISO-8859-1"))
+ (substitute* (list "texindy.pl" "xindy.pl")
+ (("our \\$clisp = .*")
+ (format #f "our $clisp = ~s;~%"
+ (search-input-file inputs "/bin/clisp")))
+ (("/usr/bin/env perl")
+ (search-input-file inputs "/bin/perl"))))))))))
+ (inputs (list clisp perl))
+ (home-page "https://ctan.org/pkg/xindy")
(synopsis "General-purpose index processor")
- (description "Xindy was developed after an impasse had been encountered in
-the attempt to complete internationalisation of @command{makeindex}. Xindy
-can be used to process indexes for documents marked up using (La)TeX, Nroff
-family and SGML-based languages. Xindy is highly configurable, both in markup
-terms and in terms of the collating order of the text being processed.")
+ (description
+ "Xindy was developed after an impasse had been encountered in the attempt
+to complete internationalisation of @command{makeindex}. Xindy can be used to
+process indexes for documents marked up using (La)TeX, Nroff family and
+SGML-based languages. Xindy is highly configurable, both in markup terms and
+in terms of the collating order of the text being processed.")
(license license:gpl2+)))
(define-public texlive-nth
- 365/418: gnu: texlive-catchfile: Remove SIMPLE-TEXLIVE-PACKAGE call., (continued)
- 365/418: gnu: texlive-catchfile: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 359/418: gnu: texlive-hyphen-package: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 360/418: gnu: texlive-tetex: Refresh package definition., guix-commits, 2023/05/29
- 362/418: gnu: texlive-hyph-utf8: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 358/418: gnu: texlive-latex-base: Refresh package definition., guix-commits, 2023/05/29
- 366/418: gnu: texlive-tabu: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 414/418: gnu: Add texlive-etex-pkg., guix-commits, 2023/05/29
- 413/418: guix: import: Improve importing texlive meta packages., guix-commits, 2023/05/29
- 412/418: guix: texlive-build-system: Handle doc-only packages gracefully., guix-commits, 2023/05/29
- 417/418: gnu: texlive-texmf: Improve package style., guix-commits, 2023/05/29
- 410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.,
guix-commits <=
- 380/418: gnu: texlive-abstract: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 379/418: gnu: texlive-babel-polish: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 392/418: gnu: texlive-etex: Fix build., guix-commits, 2023/05/29
- 385/418: gnu: texlive-soulutf8: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 386/418: gnu: texlive-totcount: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 393/418: gnu: texlive-knuth-lib: Fix build., guix-commits, 2023/05/29
- 381/418: gnu: texlive-breqn: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 384/418: gnu: texlive-soul: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 367/418: gnu: texlive-sectsty: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29
- 382/418: gnu: texlive-datatool: Remove SIMPLE-TEXLIVE-PACKAGE call., guix-commits, 2023/05/29